pub struct McpResourceClient { /* private fields */ }Expand description
Access to MCP resources through either the latest runtime or one exact step.
Implementations
Sourceimpl McpResourceClient
impl McpResourceClient
Sourcepub fn new(runtime: Arc<McpRuntime>) -> Self
pub fn new(runtime: Arc<McpRuntime>) -> Self
Creates a resource client that follows the thread’s latest published runtime.
Sourcepub fn cache_key(&self) -> McpResourceClientCacheKey
pub fn cache_key(&self) -> McpResourceClientCacheKey
Returns the identity of the connection set used by this client.
Sourcepub async fn has_server(&self, server: &str) -> bool
pub async fn has_server(&self, server: &str) -> bool
Returns whether this client can address the named server.
This does not wait for server startup.
Sourcepub async fn list_resources(
&self,
server: &str,
cursor: Option<String>,
) -> Result<McpResourcePage>
pub async fn list_resources( &self, server: &str, cursor: Option<String>, ) -> Result<McpResourcePage>
Lists one resource page from the named server.
Sourcepub async fn read_resource(
&self,
server: &str,
uri: &str,
) -> Result<McpResourceReadResult>
pub async fn read_resource( &self, server: &str, uri: &str, ) -> Result<McpResourceReadResult>
Reads one resource from the named server.